References
==========

[1] Conway, J.H., Sloane, N.J.A 1982 Fast Quantizing and Decoding Algorithms for Lattice Quantizers and Codes, Transactions of Information Theory, Vol. IT-28, NO. 2, March 1982
    * used for point quantization in An, Dn, En

[2] Conway, J.H., Sloane, N.J.A 1988 Sphere Packings, Lattices and Groups ISBN 0-387-69917-X
    * used for point quantization
    
    
    